@@ -128,3 +128,24 @@ test_that("fit_best() works with validation split: 2x 2-way splits", {
 
   expect_equal(pred, exp_pred)
 })
+
+test_that(
+  "fit_best() warns when metric or eval_time are specified in addition to parameters", {
+  skip_if_not_installed("kknn")
+
+  knn_mod <- nearest_neighbor(neighbors = tune()) %>% set_mode("regression")
+  res <-
+      tune_grid(
+      workflow(mpg ~ ., knn_mod),
+      bootstraps(mtcars),
+      control = control_grid(save_workflow = TRUE)
+   )
+   
+   tune_params <- select_best(res, metric = "rmse")
+   expect_snapshot(
+    manual_wf <- fit_best(res, metric = "rmse", parameters = tune_params)
+   )
+   expect_snapshot(
+    manual_wf <- fit_best(res, metric = "rmse", eval_time = 10, parameters = tune_params)
+   )
+})
